@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 1;
 
@@ -35,6 +35,10 @@ Structure oriented SGML/XML/HTML/etc. elements manipulation.
 
 Element utilities for 'Tags'.
 
+=item L<Tags::Output>
+
+Base class for Tags::Output::*.
+
 =item L<Tags::Output::Indent>
 
 Indent class for Tags.
@@ -59,6 +63,14 @@ Structure class for 'Tags' output.
 
 Printing 'Tags' structure by LibXML library.
 
+=item L<Tags::Utils>
+
+Utils module for Tags.
+
+=item L<Tags::Utils::Preserve>
+
+Class to check if content in element is preserved?
+
 =back
 
 =head1 REPOSITORY
@@ -79,6 +91,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
